<?php
/**
 * Copyright © 2018 Filoblu S.p.A. All rights reserved.
 */

namespace FiloBlu\EvaAttributes\Console\Command;

use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

class CreateAttributes extends Command
{

    /**
     * @var \Magento\Eav\Setup\EavSetupFactory
     */
    private $eavSetupFactory;

    /**
     * @var \FiloBlu\EvaAttributes\Helper\AttributeHelper
     */
    private $attributeHelper;

    /**
     * CreateAttributes constructor.
     * @param \Magento\Eav\Setup\EavSetupFactory $eavSetupFactory
     * @param \FiloBlu\EvaAttributes\Helper\AttributeHelper $attributeHelper
     * @param \Magento\Framework\App\State $state
     * @param \Magento\Framework\Setup\ModuleDataSetupInterface $setup
     * @param string $name
     */
    public function __construct(
        \Magento\Eav\Setup\EavSetupFactory $eavSetupFactory,
        \FiloBlu\EvaAttributes\Helper\AttributeHelper $attributeHelper,
        \Magento\Framework\App\State $state,
        \Magento\Framework\Setup\ModuleDataSetupInterface $setup,
        $name = null
    )
    {
        $this->setup = $setup;
        $this->eavSetupFactory = $eavSetupFactory;
        $this->attributeHelper = $attributeHelper;
        $this->state = $state;
        parent::__construct($name);
    }

    /**
     * {@inheritdoc}
     */
    protected function execute(
        InputInterface $input,
        OutputInterface $output
    )
    {
        //Area Code Fix
        try {
            $this->state->setAreaCode(\Magento\Framework\App\Area::AREA_GLOBAL);
        }
        catch (\Exception $e) {
            //Area code is already set
        }

        $eavSetup = $this->eavSetupFactory->create(['setup' => $this->setup]);

        $this->attributeHelper->installAttributes($eavSetup);

    }

    /**
     * {@inheritdoc}
     */
    protected function configure()
    {
        $this->setName("eva:attributes:create");
        $this->setDescription("Create Attributes");
    }
}
